@@ -6,7 +6,7 @@ import django
 
 BASE_PATH = os.path.dirname(__file__) + 'jsonfield/'
 
-def main():
+def main(db_engine='sqlite3'):
     """
     Standalone django model test with a 'memory-only-django-installation'.
     You can play with a django model without a complete django app installation.
@@ -22,14 +22,10 @@ def main():
     )
     global_settings.DATABASES = {
         'default': {
-            'ENGINE': 'django.db.backends.sqlite3',
-            'NAME': ':memory:',
+            'ENGINE': 'django.db.backends.%s' % db_engine,
+            'NAME': 'django-jsonfield',
         }
-    }
-    # Django 1.1 compat
-    global_settings.DATABASE_ENGINE = "sqlite3"
-    global_settings.DATABASE_NAME = ":memory:"
- 
+    } 
 
     global_settings.STATIC_URL = "/static/"
     global_settings.MEDIA_ROOT = os.path.join(BASE_PATH, 'static')
@@ -40,12 +36,13 @@ def main():
     from django.test.utils import get_runner
     test_runner = get_runner(global_settings)
 
-    if django.VERSION > (1,2):
-        test_runner = test_runner()
-        failures = test_runner.run_tests(['jsonfield'])
-    else:
-        failures = test_runner(['jsonfield'], verbosity=1)
+    test_runner = test_runner()
+    failures = test_runner.run_tests(['jsonfield'])
+    
     sys.exit(failures)
 
+def test_postgres():
+    main('postgresql_psycopg2')
+
 if __name__ == '__main__':
     main()
